@@ -1,4 +1,4 @@
-#' Collection of custom tidiers
+#' Custom tidiers
 #'
 #' @description
 #' \lifecycle{maturing}
@@ -27,8 +27,7 @@
 #' The tidier uses the output from `parameters::model_parameters()`, and
 #' merely takes the result and puts it in `broom::tidy()` format. To use this
 #' function with `tbl_regression()`, pass a function with the arguments for
-#' `tidy_robust()` populated. This is easily done using `purrr::partial()` e.g.
-#' `tbl_regression(tidy_fun = partial(tidy_robust, vcov = "CL"))`
+#' `tidy_robust()` populated.
 #'
 #' - `pool_and_tidy_mice()` tidier to report models resulting from multiply imputed data
 #' using the mice package. Pass the mice model object *before* the model results
@@ -40,26 +39,29 @@
 #'   `aod::wald.test()` function.
 #'   Use this tidier with `add_global_p(anova_fun = tidy_wald_test)`
 #'
-#' @inheritParams broom::tidy.glm
 #' @inheritParams tbl_regression
-#' @inheritParams add_global_p
-#' @param pool.args named list of arguments passed to `mice::pool()` in
-#' `pool_and_tidy_mice()`. Default is `NULL`
-#' @param vcov,vcov_args arguments passed to
-#' `parameters::model_parameters()`. At least one of these arguments **must**
-#' be specified.
-#' @param ... arguments passed to method;
+#' @inheritParams broom::tidy.glm
+#'
+#' @param x (`model`)\cr
+#'   Regression model object
+#' @param pool.args (named `list`)\cr
+#'   Named list of arguments passed to `mice::pool()` in
+#'   `pool_and_tidy_mice()`. Default is `NULL`
+#' @param vcov,vcov_args
+#'  Arguments passed to `parameters::model_parameters()`.
+#'  At least one of these arguments **must** be specified.
+#' @param quiet `r lifecycle::badge("deprecated")`
+#' @param ...
+#' Arguments passed to method;
 #' - `pool_and_tidy_mice()`: `mice::tidy(x, ...)`
 #' - `tidy_standardize()`: `parameters::standardize_parameters(x, ...)`
 #' - `tidy_bootstrap()`: `parameters::bootstrap_parameters(x, ...)`
 #' - `tidy_robust()`: `parameters::model_parameters(x, ...)`
 #'
-#' @param x a regression model object
 #' @name custom_tidiers
 #' @rdname custom_tidiers
 #' @export
-#' @examplesIf broom.helpers::.assert_package("effectsize", pkg_search = "gtsummary", boolean = TRUE) && broom.helpers::.assert_package("parameters", pkg_search = "gtsummary", boolean = TRUE) && broom.helpers::.assert_package("mice", pkg_search = "gtsummary", boolean = TRUE)
-#' \donttest{
+#' @examplesIf gtsummary:::is_pkg_installed(c("effectsize", "mice", "parameters"), reference_pkg = "gtsummary")
 #' # Example 1 ----------------------------------
 #' mod <- lm(age ~ marker + grade, trial)
 #'
@@ -74,51 +76,37 @@
 #'
 #' # Example 2 ----------------------------------
 #' # use "posthoc" method for coef calculation
-#' tidy_standardize_ex2 <-
-#'   tbl_regression(mod, tidy_fun = purrr::partial(tidy_standardize, method = "posthoc"))
+#' tbl_regression(mod, tidy_fun = \(x, ...) tidy_standardize(x, method = "posthoc", ...))
 #'
 #' # Example 3 ----------------------------------
 #' # Multiple Imputation using the mice package
 #' set.seed(1123)
 #' pool_and_tidy_mice_ex3 <-
-#'   suppressWarnings(mice::mice(trial, m = 2)) %>%
-#'   with(lm(age ~ marker + grade)) %>%
+#'   suppressWarnings(mice::mice(trial, m = 2)) |>
+#'   with(lm(age ~ marker + grade)) |>
 #'   tbl_regression()
-#' }
-#' @section Example Output:
-#' \if{html}{Example 1}
-#'
-#' \if{html}{\out{
-#' `r man_create_image_tag(file = "tidy_standardize_ex1.png", width = "65")`
-#' }}
-#'
-#' \if{html}{Example 2}
-#'
-#' \if{html}{\out{
-#' `r man_create_image_tag(file = "tidy_standardize_ex2.png", width = "47")`
-#' }}
-#'
-#' \if{html}{Example 3}
-#'
-#' \if{html}{\out{
-#' `r man_create_image_tag(file = "pool_and_tidy_mice_ex3.png", width = "47")`
-#' }}
-
-tidy_standardize <- function(x, exponentiate = FALSE,
+tidy_standardize <- function(x,
+                             exponentiate = FALSE,
                              conf.level = 0.95,
                              conf.int = TRUE,
-                             ..., quiet = FALSE) {
-  assert_package("effectsize", "tidy_standardize()")
-  dots <- list(...)
+                             ...,
+                             quiet = FALSE) {
+  set_cli_abort_call()
+  check_pkg_installed(c("parameters", "effectsize"), reference_pkg = "gtsummary")
+  check_scalar_logical(exponentiate)
+  check_scalar_logical(conf.int)
+  check_scalar_range(conf.level, range = c(0, 1))
+
+  if (!missing(quiet)) {
+    lifecycle::deprecate_stop(
+      when = "2.0.0",
+      what = "gtsummary::tidy_standardize(quiet)",
+      details = "Argument has been ignored."
+    )
+  }
 
   # calculating standardize coefs
-  std_coef_expr <- expr(parameters::standardize_parameters(model = x, ci = !!conf.level, !!!dots))
-  if (quiet == FALSE) {
-    inform(glue("tidy_standardize(): Estimating standardized coefs with\n  `{deparse(std_coef_expr, width.cutoff = 500L)}`"))
-  }
-  std_coef <-
-    expr(parameters::standardize_parameters(model = !!x, ci = !!conf.level, !!!dots)) %>%
-    eval()
+  std_coef <- parameters::standardize_parameters(model = x, ci = conf.level, ...)
 
   # converting output to broom::tidy format
   tidy <-
@@ -130,31 +118,38 @@ tidy_standardize <- function(x, exponentiate = FALSE,
 
   # exponentiate, if requested
   if (exponentiate) {
-    tidy <- mutate_at(tidy, vars("estimate", "conf.low", "conf.high"), exp)
+    tidy <- dplyr::mutate_at(tidy, dplyr::vars("estimate", "conf.low", "conf.high"), exp)
   }
 
   # removing conf int, if requested
-  if (!conf.int) tidy <- select(tidy, -any_of(c("conf.low", "conf.high")))
+  if (!conf.int) tidy <- dplyr::select(tidy, -any_of(c("conf.low", "conf.high")))
 
   tidy
 }
 
 #' @rdname custom_tidiers
 #' @export
-tidy_bootstrap <- function(x, exponentiate = FALSE,
+tidy_bootstrap <- function(x,
+                           exponentiate = FALSE,
                            conf.level = 0.95,
-                           conf.int = TRUE, ..., quiet = FALSE) {
-  assert_package("parameters", "tidy_bootstrap()")
-  dots <- list(...)
+                           conf.int = TRUE,
+                           ...,
+                           quiet = FALSE) {
+  set_cli_abort_call()
+  check_pkg_installed("parameters", reference_pkg = "gtsummary")
+  check_scalar_logical(exponentiate)
+  check_scalar_logical(conf.int)
+  check_scalar_range(conf.level, range = c(0, 1))
+  if (!missing(quiet)) {
+    lifecycle::deprecate_stop(
+      when = "2.0.0",
+      what = "gtsummary::tidy_standardize(quiet)",
+      details = "Argument has been ignored."
+    )
+  }
 
   # calculating bootstrapped coefs
-  boot_coef_expr <- expr(parameters::bootstrap_parameters(model = x, ci = !!conf.level, test = "p", !!!dots))
-  if (quiet == FALSE) {
-    inform(glue("tidy_bootstrap(): Estimating bootstrapped coefs with\n  `{deparse(boot_coef_expr, width.cutoff = 500L)}`"))
-  }
-  boot_coef <-
-    expr(parameters::bootstrap_parameters(model = !!x, ci = !!conf.level, test = "p", !!!dots)) %>%
-    eval()
+  boot_coef <- parameters::bootstrap_parameters(model = x, ci = conf.level, test = "p", ...)
 
   # converting output to broom::tidy format
   tidy <-
@@ -166,7 +161,7 @@ tidy_bootstrap <- function(x, exponentiate = FALSE,
 
   # exponentiate, if requested
   if (exponentiate) {
-    tidy <- mutate_at(tidy, vars("estimate", "conf.low", "conf.high"), exp)
+    tidy <- dplyr::mutate_at(tidy, vars("estimate", "conf.low", "conf.high"), exp)
   }
 
   # removing conf int, if requested
@@ -186,38 +181,39 @@ tidy_robust <- function(x,
                         vcov_args = NULL, # specify the cluster-structure
                         ...,
                         quiet = FALSE) {
-  assert_package("parameters", "tidy_robust()")
-  assert_package("insight", "tidy_robust()")
+  set_cli_abort_call()
+  check_pkg_installed(c("parameters", "insight"), reference_pkg = "gtsummary")
+  check_scalar_logical(exponentiate)
+  check_scalar_logical(conf.int)
+  check_scalar_range(conf.level, range = c(0, 1))
+  if (!missing(quiet)) {
+    lifecycle::deprecate_stop(
+      when = "2.0.0",
+      what = "gtsummary::tidy_standardize(quiet)",
+      details = "Argument has been ignored."
+    )
+  }
+
   if (is.null(vcov) && is.null(vcov_args)) {
-    paste(
-      "Arguments {.code vcov} and {.code vcov_args} have not been specified",
-      "in {.code tidy_robust()}.",
-      "Specify at least one to obtain robust standard errors."
-    ) %>%
-      cli::cli_inform()
+    cli::cli_inform(
+      c(i = "Arguments {.code vcov} and {.code vcov_args} have not been specified
+        in {.code tidy_robust()}. Specify at least one to obtain robust standard errors.")
+    )
   }
 
   dots <- rlang::dots_list(...)
   lst_model_parameters_args <-
-    rlang::inject(list(
+    inject(list(
       ci = !!conf.level,
       vcov = !!vcov,
       vcov_args = !!vcov_args,
       !!!dots
-    )) %>%
-    purrr::compact()
+    )) |>
+    compact()
 
   # calculating robust coefs
-  robust_coef_expr <-
-    expr(parameters::model_parameters(model = x, !!!lst_model_parameters_args))
-  if (quiet == FALSE) {
-    glue(
-      "tidy_robust(): Robust estimation with\n",
-      "  `{deparse(robust_coef_expr, width.cutoff = 500L)}`\n\n"
-    ) %>%
-      inform()
-  }
-  robust_coef <- eval(robust_coef_expr)
+  robust_coef <-
+    inject(parameters::model_parameters(model = x, !!!lst_model_parameters_args))
 
   # converting output to broom::tidy format ------------------------------------
   tidy <- insight::standardize_names(robust_coef, style = "broom")
@@ -225,7 +221,7 @@ tidy_robust <- function(x,
   # exponentiate, if requested -------------------------------------------------
   if (exponentiate) {
     tidy <-
-      mutate_at(tidy, vars("estimate", "conf.low", "conf.high"), exp)
+      dplyr::mutate_at(tidy, vars("estimate", "conf.low", "conf.high"), exp)
   }
 
   # removing conf int, if requested --------------------------------------------
@@ -241,50 +237,55 @@ tidy_robust <- function(x,
 #' @rdname custom_tidiers
 #' @export
 pool_and_tidy_mice <- function(x, pool.args = NULL, ..., quiet = FALSE) {
-  assert_package("mice", "pool_and_tidy_mice()")
-  if (!inherits(x, "mira")) stop("Object `x=` must be of class 'mira'.", call. = FALSE)
+  set_cli_abort_call()
+  check_pkg_installed("mice", reference_pkg = "gtsummary")
+
+  if (!missing(quiet)) {
+    lifecycle::deprecate_stop(
+      when = "2.0.0",
+      what = "gtsummary::tidy_standardize(quiet)",
+      details = "Argument has been ignored."
+    )
+  }
+
+  if (!inherits(x, "mira")) {
+    cli::cli_abort(
+      "Argument {.arg x} must be class {.cls mira}.",
+      call = get_cli_abort_call()
+    )
+  }
 
   dots <- list(...)
 
-  # printing code that will run
-  mice_expr <- expr(mice::pool(x, !!!pool.args) %>% mice::tidy(!!!dots))
-  if (quiet == FALSE) {
-    inform(glue("pool_and_tidy_mice(): Tidying mice model with\n  `{deparse(mice_expr, width.cutoff = 500L)}`"))
-  }
-
   # evaluating tidy expression
-  expr(mice::pool(!!x, !!!pool.args) %>% mice::tidy(!!!dots)) %>% eval()
+  inject(mice::pool(!!x, !!!pool.args) %>% mice::tidy(!!!dots))
 }
 
 #' @rdname custom_tidiers
 #' @export
 tidy_gam <- function(x, conf.int = FALSE, exponentiate = FALSE, conf.level = 0.95, ...) {
-  suppressWarnings(
-    broom::tidy(x,
-      conf.int = conf.int,
-      conf.level = conf.level,
-      parametric = TRUE, ...
-    )
-  ) %>%
-    # exponentiate coefs (GAM tidier does not have an `exponentiate=` argument)
-    dplyr::mutate_at(
-      vars(any_of(c("estimate", "conf.low", "conf.high"))),
-      ~ switch(exponentiate == TRUE,
-        exp(.)
-      ) %||% .
-    ) %>%
-    dplyr::mutate(parametric = TRUE) %>%
-    dplyr::bind_rows(
-      suppressWarnings(broom::tidy(x, parametric = FALSE, ...)) %>%
-        dplyr::mutate(parametric = FALSE)
-    ) %>%
+  set_cli_abort_call()
+  check_scalar_logical(exponentiate)
+  check_scalar_logical(conf.int)
+  check_scalar_range(conf.level, range = c(0, 1))
+
+  dplyr::bind_rows(
+    suppressWarnings(
+      broom::tidy(x, exponentiate = exponentiate, conf.int = conf.int,
+                  conf.level = conf.level, parametric = TRUE, ...)
+    ) |>
+      dplyr::mutate(parametric = TRUE),
+    broom::tidy(x, parametric = FALSE, ...)  |>
+      dplyr::mutate(parametric = FALSE)
+  ) |>
     dplyr::relocate("parametric", .after = dplyr::last_col())
 }
 
 #' @rdname custom_tidiers
 #' @export
 tidy_wald_test <- function(x, tidy_fun = NULL, ...) {
-  assert_package("aod", "tidy_wald_test()")
+  set_cli_abort_call()
+  check_pkg_installed(c("aod", "broom.helpers"), reference_pkg = "gtsummary")
 
   tidy_fun <- tidy_fun %||% broom.helpers::tidy_with_broom_or_parameters
 
@@ -309,10 +310,10 @@ tidy_wald_test <- function(x, tidy_fun = NULL, ...) {
           b = stats::coef(x),
           Terms = .data$model_terms_id
         ) %>%
-          list(),
-      df = .data$wald_test$result$chi2 %>% purrr::pluck("df"),
-      statistic = .data$wald_test$result$chi2 %>% purrr::pluck("chi2"),
-      p.value = .data$wald_test$result$chi2 %>% purrr::pluck("P"),
+        list(),
+      df = .data$wald_test$result$chi2 %>% getElement("df"),
+      statistic = .data$wald_test$result$chi2 %>% getElement("chi2"),
+      p.value = .data$wald_test$result$chi2 %>% getElement("P"),
     ) %>%
     dplyr::ungroup() %>%
     dplyr::select("term", "df", "statistic", "p.value")
