@@ -1,25 +1,19 @@
-#' Modify Column Alignment
+#' Modify column alignment
 #'
-#' \lifecycle{maturing}
 #' Update column alignment/justification in a gtsummary table.
 #'
 #' @inheritParams modify_table_styling
 #'
-#' @family Advanced modifiers
-#' @seealso Review [list, formula, and selector syntax][syntax] used throughout gtsummary
 #' @export
 #' @examples
-#' \donttest{
 #' # Example 1 ----------------------------------
-#' tbl <-
-#'   lm(age ~ marker + grade, trial) %>%
+#' lm(age ~ marker + grade, trial) %>%
 #'   tbl_regression() %>%
 #'   modify_column_alignment(columns = everything(), align = "left")
-#' }
 modify_column_alignment <- function(x, columns, align = c("left", "right", "center")) {
-  .assert_class(x, "gtsummary")
+  check_class(x, "gtsummary")
   updated_call_list <- c(x$call_list, list(modify_column_hide = match.call()))
-  align <- match.arg(align)
+  align <- arg_match(align)
 
   x <-
     modify_table_styling(
