@@ -1,25 +1,22 @@
-#' Stacks two or more gtsummary objects
+#' Stack tables
 #'
 #' Assists in patching together more complex tables. `tbl_stack()` appends two
-#' or more `tbl_regression`, `tbl_summary`, `tbl_svysummary`, or `tbl_merge` objects.
+#' or more gtsummary tables.
 #' Column attributes, including number formatting and column footnotes, are
 #' retained from the first passed gtsummary object.
 #'
-#' @param tbls List of gtsummary objects
-#' @param group_header Character vector with table headers where length matches
-#' the length of `tbls=`
-#' @inheritParams add_global_p
-#' @family tbl_summary tools
-#' @family tbl_svysummary tools
-#' @family tbl_regression tools
-#' @family tbl_uvregression tools
-#' @family tbl_survfit tools
-#' @seealso [tbl_merge]
+#' @param tbls (`list`)\cr
+#'   List of gtsummary objects
+#' @param group_header (`character`)\cr
+#'   Character vector with table headers where length matches the length of `tbls`
+#' @param quiet (scalar `logical`)\cr
+#'   Logical indicating whether to suppress additional messaging. Default is `FALSE`.
+#'
 #' @author Daniel D. Sjoberg
 #' @export
 #' @return A `tbl_stack` object
-#' @examples
-#' \donttest{
+#'
+#' @examplesIf (identical(Sys.getenv("NOT_CRAN"), "true") || identical(Sys.getenv("IN_PKGDOWN"), "true")) && gtsummary:::is_pkg_installed("cardx", reference_pkg = "gtsummary") && gtsummary:::is_pkg_installed("survival", reference_pkg = "cardx")
 #' # Example 1 ----------------------------------
 #' # stacking two tbl_regression objects
 #' t1 <-
@@ -37,7 +34,7 @@
 #'     label = list(trt ~ "Treatment (adjusted)")
 #'   )
 #'
-#' tbl_stack_ex1 <- tbl_stack(list(t1, t2))
+#' tbl_stack(list(t1, t2))
 #'
 #' # Example 2 ----------------------------------
 #' # stacking two tbl_merge objects
@@ -57,88 +54,60 @@
 #'     label = list(trt ~ "Treatment (adjusted)")
 #'   )
 #'
-#'
 #' # first merging, then stacking
 #' row1 <- tbl_merge(list(t1, t3), tab_spanner = c("Tumor Response", "Death"))
 #' row2 <- tbl_merge(list(t2, t4))
-#' tbl_stack_ex2 <-
-#'   tbl_stack(list(row1, row2), group_header = c("Unadjusted Analysis", "Adjusted Analysis"))
-#' }
-#' @section Example Output:
-#' \if{html}{Example 1}
 #'
-#' \if{html}{\out{
-#' `r man_create_image_tag(file = "tbl_stack_ex1.png", width = "50")`
-#' }}
-#'
-#' \if{html}{Example 2}
-#'
-#' \if{html}{\out{
-#' `r man_create_image_tag(file = "tbl_stack_ex2.png", width = "80")`
-#' }}
+#' tbl_stack(list(row1, row2), group_header = c("Unadjusted Analysis", "Adjusted Analysis"))
+tbl_stack <- function(tbls, group_header = NULL, quiet = FALSE) {
+  set_cli_abort_call()
 
-tbl_stack <- function(tbls, group_header = NULL, quiet = NULL) {
-  # setting defaults -----------------------------------------------------------
-  quiet <- quiet %||% get_theme_element("pkgwide-lgl:quiet") %||% FALSE
-
-  # input checks ---------------------------------------------------------------
-  # class of tbls
-  if (!inherits(tbls, "list")) {
-    stop("Expecting 'tbls' to be a list, e.g. 'tbls = list(tbl1, tbl2)'")
-  }
-
-  # checking all inputs are class gtsummary
-  if (!purrr::every(tbls, ~ inherits(.x, "gtsummary"))) {
-    stop("All objects in 'tbls' must be class 'gtsummary'", call. = FALSE)
-  }
-
-  # if group_header specified, then it must be a vector of same length tbls ----
-  if (!is.null(group_header) && length(tbls) != length(group_header)) {
-    stop("The length of `tbls=` and `group_header=` must match.", call. = FALSE)
-  }
+  # check inputs ---------------------------------------------------------------
+  check_class(tbls, "list")
+  walk(tbls, ~check_class(.x, "gtsummary", message = "Each element of the list {.arg tbls} must be class {.cls gtsummary}."))
+  check_scalar_logical(quiet)
+  check_class(group_header, cls = "character", allow_empty = TRUE)
+  check_length(group_header, length = length(tbls), allow_empty = TRUE)
 
   # will return call, and all arguments passed to tbl_stack
   func_inputs <- as.list(environment())
 
-  # stacking tables ------------------------------------------------------------
-  # the table_body and call_list will be updated with the tbl_stack values
-  tbl_id_colname <-
-    purrr::map(tbls, ~ pluck(.x, "table_body") %>% names()) %>%
-    unlist() %>%
-    unique() %>%
-    tbl_id_varname()
+  # stack tables ---------------------------------------------------------------
+  # first, save a string of the new tbl ID column
+  tbl_id_colname <- .tbl_id_varname(tbls)
 
+  # stack the `table_body` data frames
   results <- list()
   results$table_body <-
-    purrr::map2_dfr(
+    map2(
       tbls, seq_along(tbls),
       function(tbl, id) {
         # adding a table ID and group header
-        table_body <- pluck(tbl, "table_body") %>% mutate(!!tbl_id_colname := id)
+        table_body <- tbl[["table_body"]] |> dplyr::mutate("{tbl_id_colname}" := id)
         if (!is.null(group_header)) {
           table_body <-
-            table_body %>%
-            mutate(groupname_col = group_header[id])
+            table_body |>
+            dplyr::mutate(groupname_col = group_header[id])
         }
 
-        table_body %>% select(any_of(c("groupname_col")), matches("^tbl_id\\d+$"), everything())
+        table_body |> dplyr::select(any_of(c("groupname_col")), matches("^tbl_id\\d+$"), everything())
       }
-    )
+    ) %>%
+      dplyr::bind_rows()
 
   # creating table styling -----------------------------------------------------
   # print message if column headers, footnotes, etc. are different among tbls
-  if (identical(quiet, FALSE)) print_stack_differences(tbls)
+  if (identical(quiet, FALSE)) .print_stack_differences(tbls)
 
   results$table_styling$header <-
-    map_dfr(tbls, ~ pluck(.x, "table_styling", "header")) %>%
-    group_by(.data$column) %>%
-    filter(dplyr::row_number() == 1) %>%
-    ungroup()
+    map(tbls, ~ .x[["table_styling"]][["header"]]) |>
+    dplyr::bind_rows() |>
+    dplyr::filter(.by = "column", dplyr::row_number() == 1)
 
   # cycle over each of the styling tibbles and stack them in reverse order -----
-  for (style_type in c("footnote", "footnote_abbrev", "fmt_fun", "text_format", "fmt_missing", "cols_merge")) {
+  for (style_type in c("footnote", "footnote_abbrev", "fmt_fun", "text_format", "indent", "fmt_missing", "cols_merge")) {
     results$table_styling[[style_type]] <-
-      map_dfr(
+      map(
         rev(seq_along(tbls)),
         function(i) {
           df <- tbls[[i]]$table_styling[[style_type]]
@@ -146,35 +115,37 @@ tbl_stack <- function(tbls, group_header = NULL, quiet = NULL) {
             # adding tbl_id to the rows specifications,
             # e.g. data$tbl_id == 1L & .data$row_type != "label"
             df$rows <-
-              map(df$rows, ~ add_tbl_id_to_quo(.x, tbls[[i]]$table_body, i, tbl_id_colname, style_type))
+              map(df$rows, ~ .add_tbl_id_to_quo(.x, tbls[[i]]$table_body, i, tbl_id_colname, style_type))
           }
-          df %>%
-            mutate_at(vars(any_of(c(
+          df |>
+            dplyr::mutate_at(vars(any_of(c(
               "column", "text_interpret",
               "footnote", "format_type", "symbol"
             ))), as.character)
         }
-      )
+      ) |>
+      dplyr::bind_rows()
   }
 
   # combining rows spec for same column
   if (nrow(results$table_styling$cols_merge) > 0) {
     results$table_styling$cols_merge <-
-      results$table_styling$cols_merge %>%
-      tidyr::nest(rows = "rows") %>%
-      mutate(rows = map(.data$rows, ~ .x$rows %>% unlist()))
+      results$table_styling$cols_merge |>
+      tidyr::nest(rows = "rows") |>
+      dplyr::mutate(rows = map(.data$rows, ~ .x$rows |> unlist()))
+
     results$table_styling$cols_merge$rows <-
       map(
         results$table_styling$cols_merge$rows,
-        ~ .x %>% purrr::reduce(function(.x1, .y1) expr(!!as_expr(.x1) | !!as_expr(.y1)))
+        ~ .x |> reduce(function(.x1, .y1) expr(!!quo_squash(.x1) | !!quo_squash(.y1)))
       )
   }
 
   # take the first non-NULL element from tbls[[.]]
   for (style_type in c("caption", "source_note", "horizontal_line_above")) {
     results$table_styling[[style_type]] <-
-      map(seq_along(tbls), ~ pluck(tbls, .x, "table_styling", style_type)) %>%
-      purrr::reduce(.f = ~ .x %||% .y)
+      map(seq_along(tbls), ~ tbls[[.x]][["table_styling"]][[style_type]]) |>
+      reduce(.f = \(.x, .y) .x %||% .y)
   }
 
   # adding label for grouping variable, if present -----------------------------
@@ -196,52 +167,44 @@ tbl_stack <- function(tbls, group_header = NULL, quiet = NULL) {
 }
 
 # function prints changes to column labels and spanning headers
-print_stack_differences <- function(tbls) {
+.print_stack_differences <- function(tbls) {
   tbl_differences <-
-    purrr::map2_dfr(
+    map2(
       tbls, seq_len(length(tbls)),
-      ~ pluck(.x, "table_styling", "header") %>%
-        mutate(..tbl_id.. = .y)
-    ) %>%
-    select("..tbl_id..", "column", "label", "spanning_header") %>%
-    tidyr::pivot_longer(cols = c("label", "spanning_header")) %>%
-    group_by(.data$column, .data$name) %>%
-    mutate(
+      ~ .x[["table_styling"]][["header"]] |>
+        dplyr::mutate(..tbl_id.. = .y)
+    ) |>
+    dplyr::bind_rows() |>
+    dplyr::select("..tbl_id..", "column", "label", "spanning_header") |>
+    tidyr::pivot_longer(cols = c("label", "spanning_header")) |>
+    dplyr::group_by(.data$column, .data$name) |>
+    dplyr::mutate(
       new_value = .data$value[1],
-      name_fmt = case_when(
+      name_fmt = dplyr::case_when(
         name == "label" ~ "Column header",
         name == "spanning_header" ~ "Spanning column header"
       )
-    ) %>%
-    filter(.data$new_value != .data$value) %>%
-    ungroup() %>%
-    arrange(.data$name != "label", .data$name_fmt, .data$..tbl_id..)
+    ) |>
+    dplyr::filter(.data$new_value != .data$value) |>
+    dplyr::ungroup() |>
+    dplyr::arrange(.data$name != "label", .data$name_fmt, .data$..tbl_id..)
 
   if (nrow(tbl_differences) > 0) {
-    paste(
-      "Column headers among stacked tables differ. Headers from the first table are used.",
-      "Use {.code quiet = TRUE} to suppress this message."
-    ) %>%
-      stringr::str_wrap() %>%
-      cli_alert_info()
-
-    # purrr::pwalk(
-    #   list(tbl_differences$name_fmt, tbl_differences$..tbl_id..,
-    #        tbl_differences$column, tbl_differences$value, tbl_differences$new_value),
-    #   function(name_fmt, ..tbl_id.., column, value, new_value)
-    #     cli_alert_success("{name_fmt}, table {..tbl_id..} ({column}): {.field {value}} ---> {.field {new_value}}")
-    # )
+    cli::cli_inform(
+      c("Column headers among stacked tables differ. Headers from the first table are used.",
+         i = "Use {.code quiet = TRUE} to suppress this message.")
+    )
   }
 
   return(invisible())
 }
 
-add_tbl_id_to_quo <- function(x, table_body, tbl_id, tbl_id_colname, style_type) {
+.add_tbl_id_to_quo <- function(x, table_body, tbl_id, tbl_id_colname, style_type) {
   # if NULL AND style_type is a type that adds header changes (i.e. footnote in header),
   # then just return the NULL
   # the requires the stacking to pick one of the header footnotes and use it
   # the others will be discarded when printed.
-  row_is_null <- eval_tidy(x, data = table_body) %>% is.null()
+  row_is_null <- eval_tidy(x, data = table_body) |> is.null()
   if (row_is_null && style_type %in% c("footnote", "footnote_abbrev")) {
     return(x)
   }
@@ -254,7 +217,7 @@ add_tbl_id_to_quo <- function(x, table_body, tbl_id, tbl_id_colname, style_type)
   # if quosure, add tbl_id
   if (inherits(x, "quosure")) {
     return(
-      rlang::quo(!!sym(tbl_id_colname) == !!tbl_id & (!!rlang::f_rhs(x))) %>%
+      quo(!!sym(tbl_id_colname) == !!tbl_id & (!!rlang::f_rhs(x))) %>%
         structure(.Environment = attr(x, ".Environment"))
     )
   }
@@ -263,12 +226,14 @@ add_tbl_id_to_quo <- function(x, table_body, tbl_id, tbl_id_colname, style_type)
   expr(!!sym(tbl_id_colname) == !!tbl_id & (!!x))
 }
 
-tbl_id_varname <- function(colnames) {
+
+.tbl_id_varname <- function(tbls) {
   # get column names that begin with 'tbl_id##'
   tbl_id_colnames <-
-    stringr::str_match(string = colnames, pattern = "^tbl_id\\d+$") %>%
-    as.vector() %>%
-    purrr::discard(is.na)
+    map(tbls, ~dplyr::select(.x$table_body, matches("^tbl_id\\d+$")) |> names()) |>
+    unlist() |>
+    unique() |>
+    discard(is.na)
 
   # return 'tbl_id1' if no columns found
   if (is_empty(tbl_id_colnames)) {
@@ -277,17 +242,9 @@ tbl_id_varname <- function(colnames) {
 
   # if there are other tbl_id columns, return the next in the sequence
   tbl_max_id <-
-    stringr::str_replace(tbl_id_colnames, pattern = "^tbl_id", replacement = "") %>%
-    as.integer() %>%
+    sub(pattern = "^tbl_id", replacement = "", x = tbl_id_colnames) |>
+    as.integer() |>
     max()
 
   return(paste0("tbl_id", tbl_max_id + 1L))
 }
-
-# this function extracts the expr from a quosure, otherwise returns input
-as_expr <- function(x) {
-  if (inherits(x, "quosure")) {
-    return(rlang::f_rhs(x))
-  }
-  x
-}
